//------------------------------------------------------------------------------
//	$Id: adbcheck.js,v 1.2 2022/11/08 17:38:39 wolf Exp $
//------------------------------------------------------------------------------
//	Copyright (c) 2022 Wolfgang Stanglmeier <software@netzwolf.info>
//	This program is free software. It comes without any warranty.
//	You can redistribute it and/or modify it under the terms of the
//	"Do What The Fuck You Want To Public License" (WTFPL) Version 2,
//	as published by Sam Hocevar. See http://www.wtfpl.net/
//------------------------------------------------------------------------------
//	tries to detect adblock
//------------------------------------------------------------------------------
//	load script using "defer" or at end of body
//------------------------------------------------------------------------------

/*jsl:option explicit*/

'use strict';

(function(){

	//----------------------------------------------------------------------
	//	remove "no-script" box
	//----------------------------------------------------------------------

	const scriptBlockerContainer =
			document.getElementById( 'script-blocker-container' );

	if( scriptBlockerContainer ){

		scriptBlockerContainer.style.display = 'none';
	}

	//----------------------------------------------------------------------
	//	configuration by "data-*"-attributes of first element
	//	of class "adbd". If no such element, use body-element.
	//----------------------------------------------------------------------

	const conf = document.getElementsByClassName( 'adbd' )[0] ||
								document.body;

	//----------------------------------------------------------------------
	//		numeric parameter
	//----------------------------------------------------------------------

	const startDelay = parseInt(
		conf.getAttribute( 'data-adbd-start-delay'), 10 ) || 100;
	const interval = parseInt(
		conf.getAttribute( 'data-adbd-interval'   ), 10 ) || 100;
	const nTries = parseInt(
		conf.getAttribute( 'data-adbd-n-tries '   ), 10 ) || 10;

	//----------------------------------------------------------------------
	//		class name parameter
	//----------------------------------------------------------------------

	const classNameBlocked = conf.getAttribute(
		'data-adbd-class-adb-detected' )    || 'adb-detected';

	const classNameNotBlocked = conf.getAttribute(
		'data-adbd-class-no-adb-detected' ) || 'no-adb-detected';

	//----------------------------------------------------------------------
	//		bait class name parameter
	//----------------------------------------------------------------------

	const baitClassName = conf.getAttribute( 'data-adbd-bait-class' ) ||
		[
			'ADBox',
			'AD_area',
			'AdBar',
			'AdsRec',
			'Ads_4',
			'GoogleAd',
			'HomeAds',
			'InArticleAd',
			'LeftAd',
			'SidebarAd',
			'ad-300-250',
			'ad-banner',
			'ad_zone',
			'adarea',
			'adbanner',
			'adbar',
			'adboard',
			'adbox1',
			'admain',
			'ads-area',
			'ads-banner',
			'ads-banner',
			'adsbox',
			'adsense-ad',
			'banner_ad',
			'box_ad',
			'googad',
			'google-ad',
			'google-ads',
			'pub_300x250',
			'pub_300x250m',
			'pub_728x90',
			'text-ad',
			'text-ad-links',
			'text-ads',
			'textAd',
			'text_ad',
			'text_ads'
		].join( '\x20' );

	//----------------------------------------------------------------------
	//		bait style parameter
	//----------------------------------------------------------------------

	const baitStyle = conf.getAttribute( 'data-adbd-bait-style' ) ||
		[
			'position: absolute !important',
			'top: 1px !important',
			'left: 1px !important',
			// 'top: -1000px !important',
			// 'left: -10000px !important',
			'width: 1px !important',
			'height: 1px !important'
		].join( ';\x20' );

	//----------------------------------------------------------------------
	//		debug parameter
	//----------------------------------------------------------------------

	const log = console[ conf.getAttribute( 'data-adbd-debug' ) || ''];

	//----------------------------------------------------------------------
	//	fill empty elements if script active
	//----------------------------------------------------------------------

	function copyContent( id ){

		if( !id ){ return; }

		const element = document.getElementById( id );
		if( !element ){ return; }

		const html = element.getAttribute( 'data-content' );
		if( html ){ element.innerHTML = html; }
	}

	//----------------------------------------------------------------------
	//	create bait
	//----------------------------------------------------------------------

	const bait = document.createElement( 'div' );

	bait.className     = baitClassName;
	bait.style.cssText = baitStyle;

	document.body.appendChild( bait );

	//----------------------------------------------------------------------
	//	test if bait was hidden by an ad blocker
	//----------------------------------------------------------------------

	function checkBait( ){

		//--------------------------------------------------------------
		//	effective sizes
		//--------------------------------------------------------------

		var res = document.body.getAttribute( 'abp' ) ||
			!bait.offsetParent ||
			!bait.offsetHeight ||
			!bait.offsetLeft   ||
			!bait.offsetTop    ||
			!bait.offsetWidth  ||
			!bait.clientHeight ||
			!bait.clientWidth;

		//--------------------------------------------------------------
		//	computed style
		//--------------------------------------------------------------

		const cs = window.getComputedStyle &&
					window.getComputedStyle( bait );

		if( cs ){
			if( cs.getPropertyValue( 'display'    ) == 'none'   ){
				res = true; }
			if( cs.getPropertyValue( 'visibility' ) == 'hidden' ){
				res = true; }
		}

		log && log( 'check: ' + res );
		return res;
	}

	//----------------------------------------------------------------------
	//	check loop
	//----------------------------------------------------------------------

	var checker = function( round ){

		++round;
		const detected = checkBait();

		//--------------------------------------------------------------
		//	no adblocker detected and more tries available
		//--------------------------------------------------------------

		if( !detected && round < nTries ){

			window.setTimeout( function(){

				checker( round );
			}, interval );
			return;
		}

		//--------------------------------------------------------------
		//	adblocker detected or last try
		//--------------------------------------------------------------

		document.body.removeChild( bait );

		//--------------------------------------------------------------
		//	process result
		//--------------------------------------------------------------

		log && log( 'detected: ' + detected );

		//--------------------------------------------------------------
		//	process result
		//--------------------------------------------------------------

		if( detected ){

			copyContent( 'adblocker-container' );
			document.body.classList.add( classNameBlocked );
		} else {

			copyContent( 'no-adblocker-container' );
			document.body.classList.add( classNameNotBlocked );
		}
	};

	//----------------------------------------------------------------------
	//	start first try
	//----------------------------------------------------------------------

	window.setTimeout( function( ){

		checker( 0 );
	}, startDelay );
})();

//------------------------------------------------------------------------------
//	$Id: adbcheck.js,v 1.2 2022/11/08 17:38:39 wolf Exp $
//------------------------------------------------------------------------------
